#
# spec file for package python-urlextract
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-urlextract
Version:        1.9.0
Release:        2.2
Summary:        Collects and extracts URLs from given text
License:        MIT
URL:            https://github.com/lipoja/URLExtract
Source:         https://github.com/lipoja/URLExtract/archive/v%{version}.tar.gz#/urlextract-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-dnspython
Requires:       python-filelock
Requires:       python-idna
Requires:       python-platformdirs
Requires:       python-uritools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module dnspython}
BuildRequires:  %{python_module filelock}
BuildRequires:  %{python_module idna}
BuildRequires:  %{python_module platformdirs}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module uritools}
# /SECTION
%python_subpackages

%description
Collects and extracts URLs from given text.

%prep
%setup -q -n URLExtract-%{version}
sed -i '1{/^#!/d}' urlextract/*.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/urlextract
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not test_dns'
find %{buildroot} -name tlds-alpha-by-domain.txt.lock -delete # avoid modification of build results by tests

%post
%python_install_alternative urlextract

%postun
%python_uninstall_alternative urlextract

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/urlextract
%{python_sitelib}/*urlextract*/

%changelog
* Mon Mar 25 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Avoid modification of build results by tests
* Tue Mar 19 2024 Dirk Müller <dmueller@suse.com>
- update to 1.9.0:
  * Adding support for Python 3.12
  * Accepting only ASCII characters left from TLD.
  * Fixing parsing of Markdown links
  * Fixing filter of mixed case hostnames
  * updated list of TLDs
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.8.0:
  * adding ability to filter out mixed case hostnames (issue
    [#143])
  * adding the ability to set stop characters inside of scheme -
    default stop chars ':' (issue #82)
  * Fix index issue with uppercase characters in domain names
  * updated GitHub Action test
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.7.1
  * fixes urlextract without authority causes AttributeError
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.7.0
  * correct handling when authority starts with @ symbol
  * remove unreserved characters from the beginning of found URL
  * added typing and mypy checkcs - by mimi89999
  * updated list of TLDs
* Wed Aug 17 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.6.0
  * Add a list of URLs allowed to extract
  * Updating tests with correct order of actual == expected
  * Update list of TLDs
- from v1.5.0
  * Fix incorrect indices when TLD is found twice
  * Replace unmaintained appdirs with maintained platformdirs
  * update README, code style and code formatting using black
  * updated list of TLDs
- from v1.4.0
  * urlextract detects URLs which start with double slash '//'
  * adding ability to return only URLs with schema
- from v1.3.0
  * fixing None of the cache directory is writable
  * fixes RE for IPv4 addresses
  * updated list of TLDs
  * urlextract cli is telling people to report errors on GitHub
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Dec 26 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.14.0
